@@ -46,6 +46,8 @@ class Config
         bool bSaveSerials;
         bool bPlatformDetection;
         bool bShowWishlist;
+        bool bAutomaticXMLCreation;
+        bool bSaveChangelogs;
         std::string sGameRegex;
         std::string sDirectory;
         std::string sCacheDirectory;
@@ -59,6 +61,7 @@ class Config
         std::string sCookiePath;
         std::string sConfigFilePath;
         std::string sBlacklistFilePath;
+        std::string sIgnorelistFilePath;
         std::string sOrphanRegex;
         std::string sCoverList;
         std::string sReportFilePath;
@@ -86,6 +89,7 @@ class Config
         curl_off_t iDownloadRate;
         long int iTimeout;
         Blacklist blacklist;
+        Blacklist ignorelist;
 };
 
 #endif // CONFIG_H__
