@@ -24,6 +24,7 @@
 #include "config.h"
 #include "api.h"
 #include "progressbar.h"
+#include "website.h"
 #include <curl/curl.h>
 #include <json/json.h>
 #include <ctime>
@@ -47,13 +48,6 @@ class Timer
         struct timeval last_update;
 };
 
-class gameItem {
-    public:
-        std::string name;
-        std::string id;
-        std::vector<std::string> dlcnames;
-};
-
 class Downloader
 {
     public:
@@ -90,20 +84,18 @@ class Downloader
         int loadGameDetailsCache();
         int saveGameDetailsCache();
         std::vector<gameDetails> getGameDetailsFromJsonNode(Json::Value root, const int& recursion_level = 0);
-        int HTTP_Login(const std::string& email, const std::string& password);
-        std::vector<gameItem> getGames();
-        std::vector<gameItem> getFreeGames();
         std::vector<gameFile> getExtrasFromJSON(const Json::Value& json, const std::string& gamename);
-        Json::Value getGameDetailsJSON(const std::string& gameid);
         std::string getSerialsFromJSON(const Json::Value& json);
         void saveSerials(const std::string& serials, const std::string& filepath);
+        std::string getChangelogFromJSON(const Json::Value& json);
+        void saveChangelog(const std::string& changelog, const std::string& filepath);
 
-        static int progressCallback(void *clientp, double dltotal, double dlnow, double ultotal, double ulnow);
+        static int progressCallback(void *clientp, curl_off_t dltotal, curl_off_t dlnow, curl_off_t ultotal, curl_off_t ulnow);
         static size_t writeMemoryCallback(char *ptr, size_t size, size_t nmemb, void *userp);
         static size_t writeData(void *ptr, size_t size, size_t nmemb, FILE *stream);
         static size_t readData(void *ptr, size_t size, size_t nmemb, FILE *stream);
 
-
+        Website *gogWebsite;
         API *gogAPI;
         std::vector<gameItem> gameItems;
         std::vector<gameDetails> games;
