@@ -20,12 +20,51 @@
 #include <boost/regex.hpp>
 #include <json/json.h>
 
+struct gameSpecificDirectoryConfig
+{
+    bool bSubDirectories;
+    std::string sDirectory;
+    std::string sGameSubdir;
+    std::string sInstallersSubdir;
+    std::string sExtrasSubdir;
+    std::string sPatchesSubdir;
+    std::string sLanguagePackSubdir;
+    std::string sDLCSubdir;
+};
+
 struct gameSpecificConfig
 {
     unsigned int iInstallerPlatform;
     unsigned int iInstallerLanguage;
     bool bDLC;
     bool bIgnoreDLCCount;
+    gameSpecificDirectoryConfig dirConf;
+    std::vector<unsigned int> vLanguagePriority;
+    std::vector<unsigned int> vPlatformPriority;
+};
+
+struct gameItem
+{
+    std::string name;
+    std::string id;
+    std::vector<std::string> dlcnames;
+    Json::Value gamedetailsjson;
+};
+
+struct wishlistItem
+{
+    std::string title;
+    unsigned int platform;
+    std::vector<std::string> tags;
+    time_t release_date_time;
+    std::string currency;
+    std::string price;
+    std::string discount_percent;
+    std::string discount;
+    std::string store_credit;
+    std::string url;
+    bool bIsBonusStoreCreditIncluded;
+    bool bIsDiscounted;
 };
 
 namespace Util
@@ -48,6 +87,7 @@ namespace Util
     std::vector<std::string> tokenize(const std::string& str, const std::string& separator = ",");
     unsigned int getOptionValue(const std::string& str, const std::vector<GlobalConstants::optionsStruct>& options);
     std::string getOptionNameString(const unsigned int& value, const std::vector<GlobalConstants::optionsStruct>& options);
+    void parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options);
 }
 
 #endif // UTIL_H
