@@ -13,12 +13,6 @@
 #include <boost/filesystem.hpp>
 #include <boost/program_options.hpp>
 
-#define VERSION_NUMBER "2.26"
-
-#ifndef VERSION_STRING
-#   define VERSION_STRING "LGOGDownloader " VERSION_NUMBER
-#endif
-
 namespace bpo = boost::program_options;
 
 template<typename T> void set_vm_value(std::map<std::string, bpo::variable_value>& vm, const std::string& option, const T& value)
@@ -26,24 +20,6 @@ template<typename T> void set_vm_value(std::map<std::string, bpo::variable_value
     vm[option].value() = boost::any(value);
 }
 
-// Parse the options string
-void parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options)
-{
-    type = 0;
-    std::vector<std::string> tokens_priority = Util::tokenize(option_string, ",");
-    for (std::vector<std::string>::iterator it_priority = tokens_priority.begin(); it_priority != tokens_priority.end(); it_priority++)
-    {
-        unsigned int value = 0;
-        std::vector<std::string> tokens_value = Util::tokenize(*it_priority, "+");
-        for (std::vector<std::string>::iterator it_value = tokens_value.begin(); it_value != tokens_value.end(); it_value++)
-        {
-            value |= Util::getOptionValue(*it_value, options);
-        }
-        priority.push_back(value);
-        type |= value;
-    }
-}
-
 int main(int argc, char *argv[])
 {
     // Constants for option selection with include/exclude
@@ -78,6 +54,7 @@ int main(int argc, char *argv[])
     config.sCookiePath = config.sConfigDirectory + "/cookies.txt";
     config.sConfigFilePath = config.sConfigDirectory + "/config.cfg";
     config.sBlacklistFilePath = config.sConfigDirectory + "/blacklist.txt";
+    config.sIgnorelistFilePath = config.sConfigDirectory + "/ignorelist.txt";
 
     std::string priority_help_text = "Set priority by separating values with \",\"\nCombine values by separating with \"+\"";
     // Create help text for --platform option
@@ -198,6 +175,8 @@ int main(int argc, char *argv[])
             ("ignore-dlc-count", bpo::value<std::string>(&config.sIgnoreDLCCountRegex)->implicit_value(".*"), "Set regular expression filter for games to ignore DLC count information\nIgnoring DLC count information helps in situations where the account page doesn't provide accurate information about DLCs")
             ("include", bpo::value<std::string>(&sIncludeOptions)->default_value("all"), ("Select what to download/list/repair\n" + include_options_text).c_str())
             ("exclude", bpo::value<std::string>(&sExcludeOptions)->default_value("covers"), ("Select what not to download/list/repair\n" + include_options_text).c_str())
+            ("automatic-xml-creation", bpo::value<bool>(&config.bAutomaticXMLCreation)->zero_tokens()->default_value(false), "Automatically create XML data after download has completed")
+            ("save-changelogs", bpo::value<bool>(&config.bSaveChangelogs)->zero_tokens()->default_value(false), "Save changelogs when downloading")
         ;
         // Options read from config file
         options_cfg_only.add_options()
@@ -232,7 +211,7 @@ int main(int argc, char *argv[])
         {
             if (!boost::filesystem::create_directories(path))
             {
-                std::cout << "Failed to create directory: " << path << std::endl;
+                std::cerr << "Failed to create directory: " << path << std::endl;
                 return 1;
             }
         }
@@ -242,7 +221,7 @@ int main(int argc, char *argv[])
         {
             if (!boost::filesystem::create_directories(path))
             {
-                std::cout << "Failed to create directory: " << path << std::endl;
+                std::cerr << "Failed to create directory: " << path << std::endl;
                 return 1;
             }
         }
@@ -252,7 +231,7 @@ int main(int argc, char *argv[])
         {
             if (!boost::filesystem::create_directories(path))
             {
-                std::cout << "Failed to create directory: " << path << std::endl;
+                std::cerr << "Failed to create directory: " << path << std::endl;
                 return 1;
             }
         }
@@ -262,7 +241,7 @@ int main(int argc, char *argv[])
             std::ifstream ifs(config.sConfigFilePath.c_str());
             if (!ifs)
             {
-                std::cout << "Could not open config file: " << config.sConfigFilePath << std::endl;
+                std::cerr << "Could not open config file: " << config.sConfigFilePath << std::endl;
                 return 1;
             }
             else
@@ -279,7 +258,7 @@ int main(int argc, char *argv[])
             std::ifstream ifs(config.sBlacklistFilePath.c_str());
             if (!ifs)
             {
-                std::cout << "Could not open blacklist file: " << config.sBlacklistFilePath << std::endl;
+                std::cerr << "Could not open blacklist file: " << config.sBlacklistFilePath << std::endl;
                 return 1;
             }
             else
@@ -295,6 +274,27 @@ int main(int argc, char *argv[])
             }
         }
 
+        if (boost::filesystem::exists(config.sIgnorelistFilePath))
+        {
+            std::ifstream ifs(config.sIgnorelistFilePath.c_str());
+            if (!ifs)
+            {
+                std::cerr << "Could not open ignorelist file: " << config.sIgnorelistFilePath << std::endl;
+                return 1;
+            }
+            else
+            {
+                std::string line;
+                std::vector<std::string> lines;
+                while (!ifs.eof())
+                {
+                    std::getline(ifs, line);
+                    lines.push_back(std::move(line));
+                }
+                config.ignorelist.initialize(lines);
+            }
+        }
+
         if (vm.count("chunk-size"))
             config.iChunkSize <<= 20; // Convert chunk size from bytes to megabytes
 
@@ -344,8 +344,11 @@ int main(int argc, char *argv[])
             config.bLoginHTTP = true;
         }
 
-        parseOptionString(sInstallerLanguage, config.vLanguagePriority, config.iInstallerLanguage, GlobalConstants::LANGUAGES);
-        parseOptionString(sInstallerPlatform, config.vPlatformPriority, config.iInstallerPlatform, GlobalConstants::PLATFORMS);
+        if (config.sXMLFile == "automatic")
+            config.bAutomaticXMLCreation = true;
+
+        Util::parseOptionString(sInstallerLanguage, config.vLanguagePriority, config.iInstallerLanguage, GlobalConstants::LANGUAGES);
+        Util::parseOptionString(sInstallerPlatform, config.vPlatformPriority, config.iInstallerPlatform, GlobalConstants::PLATFORMS);
 
         unsigned int include_value = 0;
         unsigned int exclude_value = 0;
@@ -383,13 +386,13 @@ int main(int argc, char *argv[])
 
     if (config.iInstallerPlatform < GlobalConstants::PLATFORMS[0].id || config.iInstallerPlatform > platform_all)
     {
-        std::cout << "Invalid value for --platform" << std::endl;
+        std::cerr << "Invalid value for --platform" << std::endl;
         return 1;
     }
 
     if (config.iInstallerLanguage < GlobalConstants::LANGUAGES[0].id || config.iInstallerLanguage > language_all)
     {
-        std::cout << "Invalid value for --language" << std::endl;
+        std::cerr << "Invalid value for --language" << std::endl;
         return 1;
     }
 
@@ -451,12 +454,11 @@ int main(int argc, char *argv[])
         {
             set_vm_value(vm, "token", downloader.config.sToken);
             set_vm_value(vm, "secret", downloader.config.sSecret);
-            bpo::notify(vm);
         }
         std::ofstream ofs(config.sConfigFilePath.c_str());
         if (ofs)
         {
-            std::cout << "Saving config: " << config.sConfigFilePath << std::endl;
+            std::cerr << "Saving config: " << config.sConfigFilePath << std::endl;
             for (bpo::variables_map::iterator it = vm.begin(); it != vm.end(); ++it)
             {
                 std::string option = it->first;
@@ -507,7 +509,7 @@ int main(int argc, char *argv[])
         }
         else
         {
-            std::cout << "Failed to create config: " << config.sConfigFilePath << std::endl;
+            std::cerr << "Failed to create config: " << config.sConfigFilePath << std::endl;
             return 1;
         }
     }
@@ -527,7 +529,7 @@ int main(int argc, char *argv[])
         }
         else
         {
-            std::cout << "Failed to create config: " << config.sConfigFilePath << std::endl;
+            std::cerr << "Failed to create config: " << config.sConfigFilePath << std::endl;
             return 1;
         }
     }
@@ -555,9 +557,13 @@ int main(int argc, char *argv[])
     else if (config.bCheckStatus)
         downloader.checkStatus();
     else
-    {   // Show help message
-        std::cout   << config.sVersionString << std::endl
-                    << options_cli_all << std::endl;
+    {
+        if (!(config.bLoginAPI || config.bLoginHTTP))
+        {
+            // Show help message
+            std::cerr   << config.sVersionString << std::endl
+                        << options_cli_all << std::endl;
+        }
     }
 
     // Orphan check was called at the same time as download. Perform it after download has finished
