@@ -1,5 +1,10 @@
+/* This program is free software. It comes without any warranty, to
+ * the extent permitted by applicable law. You can redistribute it
+ * and/or modify it under the terms of the Do What The Fuck You Want
+ * To Public License, Version 2, as published by Sam Hocevar. See
+ * http://www.wtfpl.net/ for more details. */
+
 #include "gamedetails.h"
-#include "util.h"
 
 gameDetails::gameDetails()
 {
@@ -11,7 +16,7 @@ gameDetails::~gameDetails()
     //dtor
 }
 
-void gameDetails::filterWithPriorities(const Config& config)
+void gameDetails::filterWithPriorities(const gameSpecificConfig& config)
 {
     if (config.vPlatformPriority.empty() && config.vLanguagePriority.empty())
         return;
@@ -21,7 +26,7 @@ void gameDetails::filterWithPriorities(const Config& config)
     filterListWithPriorities(languagepacks, config);
 }
 
-void gameDetails::filterListWithPriorities(std::vector<gameFile>& list, const Config& config)
+void gameDetails::filterListWithPriorities(std::vector<gameFile>& list, const gameSpecificConfig& config)
 {
     /*
       Compute the score of each item - we use a scoring mechanism and we keep all ties
@@ -66,12 +71,13 @@ void gameDetails::filterListWithPriorities(std::vector<gameFile>& list, const Co
         }
 }
 
-void gameDetails::makeFilepaths(const Config& config)
+void gameDetails::makeFilepaths(const gameSpecificDirectoryConfig& config)
 {
     std::string filepath;
     std::string directory = config.sDirectory + "/" + config.sGameSubdir + "/";
     std::string subdir;
     this->serialsFilepath = Util::makeFilepath(directory, "serials.txt", this->gamename, subdir, 0);
+    this->changelogFilepath = Util::makeFilepath(directory, "changelog_" + gamename + ".html", this->gamename, subdir, 0);
 
     for (unsigned int i = 0; i < this->installers.size(); ++i)
     {
@@ -105,6 +111,7 @@ void gameDetails::makeFilepaths(const Config& config)
     {
         subdir = config.bSubDirectories ? config.sDLCSubdir + "/" + config.sInstallersSubdir : "";
         this->dlcs[i].serialsFilepath = Util::makeFilepath(directory, "serials.txt", this->gamename, subdir, 0);
+        this->dlcs[i].changelogFilepath = Util::makeFilepath(directory, "changelog_" + this->dlcs[i].gamename + ".html", this->gamename, subdir, 0);
         for (unsigned int j = 0; j < this->dlcs[i].installers.size(); ++j)
         {
             subdir = config.bSubDirectories ? config.sDLCSubdir + "/" + config.sInstallersSubdir : "";
@@ -136,6 +143,7 @@ Json::Value gameDetails::getDetailsAsJson()
     json["title"] = this->title;
     json["icon"] = this->icon;
     json["serials"] = this->serials;
+    json["changelog"] = this->changelog;
 
     for (unsigned int i = 0; i < this->extras.size(); ++i)
         json["extras"].append(this->extras[i].getAsJson());
@@ -161,3 +169,8 @@ std::string gameDetails::getSerialsFilepath()
 {
     return this->serialsFilepath;
 }
+
+std::string gameDetails::getChangelogFilepath()
+{
+    return this->changelogFilepath;
+}
