@@ -64,7 +64,7 @@ std::string Util::getFileHash(const std::string& filename, unsigned hash_id)
     rhash_library_init();
     int i = rhash_file(hash_id, filename.c_str(), digest);
     if (i < 0)
-        std::cout << "LibRHash error: " << strerror(errno) << std::endl;
+        std::cerr << "LibRHash error: " << strerror(errno) << std::endl;
     else
         rhash_print_bytes(result, digest, rhash_get_digest_size(hash_id), RHPR_HEX);
 
@@ -79,7 +79,7 @@ std::string Util::getChunkHash(unsigned char *chunk, uintmax_t chunk_size, unsig
     rhash_library_init();
     int i = rhash_msg(hash_id, chunk, chunk_size, digest);
     if (i < 0)
-        std::cout << "LibRHash error: " << strerror(errno) << std::endl;
+        std::cerr << "LibRHash error: " << strerror(errno) << std::endl;
     else
         rhash_print_bytes(result, digest, rhash_get_digest_size(hash_id), RHPR_HEX);
 
@@ -104,7 +104,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
     boost::filesystem::path path = xml_dir;
     if (!boost::filesystem::exists(path)) {
         if (!boost::filesystem::create_directories(path)) {
-            std::cout << "Failed to create directory: " << path << std::endl;
+            std::cerr << "Failed to create directory: " << path << std::endl;
             return res;
         }
     }
@@ -115,7 +115,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
         filesize = ftell(infile);
         rewind(infile);
     } else {
-        std::cout << filepath << " doesn't exist" << std::endl;
+        std::cerr << filepath << " doesn't exist" << std::endl;
         return res;
     }
 
@@ -159,13 +159,13 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
         unsigned char *chunk = (unsigned char *) malloc(chunk_size * sizeof(unsigned char *));
         if (chunk == NULL)
         {
-            std::cout << "Memory error" << std::endl;
+            std::cerr << "Memory error" << std::endl;
             return res;
         }
         size = fread(chunk, 1, chunk_size, infile);
         if (size != chunk_size)
         {
-            std::cout << "Read error" << std::endl;
+            std::cerr << "Read error" << std::endl;
             free(chunk);
             return res;
         }
@@ -204,7 +204,7 @@ int Util::createXML(std::string filepath, uintmax_t chunk_size, std::string xml_
         fclose(xmlfile);
         res = 1;
     } else {
-        std::cout << "Can't create " << filenameXML << std::endl;
+        std::cerr << "Can't create " << filenameXML << std::endl;
         return res;
     }
 
@@ -240,12 +240,22 @@ int Util::getGameSpecificConfig(std::string gamename, gameSpecificConfig* conf,
     {
         if (root.isMember("language"))
         {
-            conf->iInstallerLanguage = root["language"].asUInt();
+            if (root["language"].isInt())
+                conf->iInstallerLanguage = root["language"].asUInt();
+            else
+            {
+                Util::parseOptionString(root["language"].asString(), conf->vLanguagePriority, conf->iInstallerLanguage, GlobalConstants::LANGUAGES);
+            }
             res++;
         }
         if (root.isMember("platform"))
         {
-            conf->iInstallerPlatform = root["platform"].asUInt();
+            if (root["platform"].isInt())
+                conf->iInstallerPlatform = root["platform"].asUInt();
+            else
+            {
+                Util::parseOptionString(root["platform"].asString(), conf->vPlatformPriority, conf->iInstallerPlatform, GlobalConstants::PLATFORMS);
+            }
             res++;
         }
         if (root.isMember("dlc"))
@@ -258,11 +268,51 @@ int Util::getGameSpecificConfig(std::string gamename, gameSpecificConfig* conf,
             conf->bIgnoreDLCCount = root["ignore-dlc-count"].asBool();
             res++;
         }
+        if (root.isMember("subdirectories"))
+        {
+            conf->dirConf.bSubDirectories = root["subdirectories"].asBool();
+            res++;
+        }
+        if (root.isMember("directory"))
+        {
+            conf->dirConf.sDirectory = root["directory"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-game"))
+        {
+            conf->dirConf.sGameSubdir = root["subdir-game"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-installers"))
+        {
+            conf->dirConf.sInstallersSubdir = root["subdir-installers"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-extras"))
+        {
+            conf->dirConf.sExtrasSubdir = root["subdir-extras"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-patches"))
+        {
+            conf->dirConf.sPatchesSubdir = root["subdir-patches"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-language-packs"))
+        {
+            conf->dirConf.sLanguagePackSubdir = root["subdir-language-packs"].asString();
+            res++;
+        }
+        if (root.isMember("subdir-dlc"))
+        {
+            conf->dirConf.sDLCSubdir = root["subdir-dlc"].asString();
+            res++;
+        }
     }
     else
     {
-        std::cout << "Failed to parse game specific config" << std::endl;
-        std::cout << jsonparser->getFormattedErrorMessages() << std::endl;
+        std::cerr << "Failed to parse game specific config " << filepath << std::endl;
+        std::cerr << jsonparser->getFormattedErrorMessages() << std::endl;
     }
     delete jsonparser;
     if (json)
@@ -320,7 +370,7 @@ void Util::setFilePermissions(const boost::filesystem::path& path, const boost::
                 boost::filesystem::permissions(path, permissions, ec);
                 if (ec)
                 {
-                    std::cout << "Failed to set file permissions for " << path.string() << std::endl;
+                    std::cerr << "Failed to set file permissions for " << path.string() << std::endl;
                 }
             }
         }
@@ -338,11 +388,11 @@ int Util::getTerminalWidth()
 void Util::getDownloaderUrlsFromJSON(const Json::Value &root, std::vector<std::string> &urls)
 {
     if(root.size() > 0) {
-        for(Json::ValueIterator it = root.begin() ; it != root.end() ; ++it)
+        for(Json::ValueConstIterator it = root.begin() ; it != root.end() ; ++it)
         {
             if (it.key() == "downloaderUrl")
             {
-                Json::Value& url = *it;
+                Json::Value url = *it;
                 urls.push_back(url.asString());
             }
             else
@@ -471,3 +521,22 @@ std::string Util::getOptionNameString(const unsigned int& value, const std::vect
     }
     return str;
 }
+
+// Parse the options string
+void Util::parseOptionString(const std::string &option_string, std::vector<unsigned int> &priority, unsigned int &type, const std::vector<GlobalConstants::optionsStruct>& options)
+{
+    type = 0;
+    priority.clear();
+    std::vector<std::string> tokens_priority = Util::tokenize(option_string, ",");
+    for (std::vector<std::string>::iterator it_priority = tokens_priority.begin(); it_priority != tokens_priority.end(); it_priority++)
+    {
+        unsigned int value = 0;
+        std::vector<std::string> tokens_value = Util::tokenize(*it_priority, "+");
+        for (std::vector<std::string>::iterator it_value = tokens_value.begin(); it_value != tokens_value.end(); it_value++)
+        {
+            value |= Util::getOptionValue(*it_value, options);
+        }
+        priority.push_back(value);
+        type |= value;
+    }
+}
